=== modified file 'client/drizzleslap.cc'
--- client/drizzleslap.cc	2010-11-01 03:30:01 +0000
+++ client/drizzleslap.cc	2010-11-02 15:29:06 +0000
@@ -78,6 +78,7 @@
 #include "stats.h"
 #include "thread_context.h"
 #include "conclusions.h"
+#include "wakeup.h"
 
 #include <signal.h>
 #include <stdarg.h>
@@ -94,6 +95,7 @@
 #include <iostream>
 #include <fstream>
 #include <drizzled/configmake.h>
+
 /* Added this for string translation. */
 #include <drizzled/gettext.h>
 
@@ -120,9 +122,8 @@
 uint32_t thread_counter;
 boost::mutex counter_mutex;
 boost::condition_variable_any count_threshhold;
-bool master_wakeup;
-boost::mutex sleeper_mutex;
-boost::condition_variable_any sleep_threshhold;
+
+client::Wakeup master_wakeup;
 
 /* Global Thread timer */
 static bool timer_alarm= false;
@@ -169,18 +170,18 @@
   num_char_cols_opt,
   num_int_cols_opt;
 string opt_label;
-static unsigned int opt_set_random_seed;
+static uint32_t opt_set_random_seed;
 
 string auto_generate_selected_columns_opt;
 
 /* Yes, we do set defaults here */
-static unsigned int num_int_cols= 1;
-static unsigned int num_char_cols= 1;
-static unsigned int num_blob_cols= 0;
-static unsigned int num_blob_cols_size;
-static unsigned int num_blob_cols_size_min;
-static unsigned int num_int_cols_index= 0;
-static unsigned int num_char_cols_index= 0;
+static uint32_t num_int_cols= 1;
+static uint32_t num_char_cols= 1;
+static uint32_t num_blob_cols= 0;
+static uint32_t num_blob_cols_size;
+static uint32_t num_blob_cols_size_min;
+static uint32_t num_int_cols_index= 0;
+static uint32_t num_char_cols_index= 0;
 static uint32_t iterations;
 static uint64_t actual_queries= 0;
 static uint64_t auto_actual_queries;
@@ -193,7 +194,6 @@
 string create_string;
 std::vector <uint32_t> concurrency;
 
-const char *default_dbug_option= "d:t:o,/tmp/drizzleslap.trace";
 std::string opt_csv_str;
 int csv_file;
 
@@ -207,35 +207,33 @@
 static Statement *create_statements= NULL;
 
 static std::vector <Statement *> query_statements;
-static unsigned int query_statements_count;
+static uint32_t query_statements_count;
 
 
 /* Prototypes */
-void print_conclusions(Conclusions *con);
-void print_conclusions_csv(Conclusions *con);
+void print_conclusions(Conclusions &con);
+void print_conclusions_csv(Conclusions &con);
 void generate_stats(Conclusions *con, OptionString *eng, Stats *sptr);
 uint32_t parse_comma(const char *string, std::vector <uint32_t> &range);
 uint32_t parse_delimiter(const char *script, Statement **stmt, char delm);
 uint32_t parse_option(const char *origin, OptionString **stmt, char delm);
-static int drop_schema(drizzle_con_st *con, const char *db);
+static void drop_schema(drizzle_con_st &con, const char *db);
 uint32_t get_random_string(char *buf, size_t size);
 static Statement *build_table_string(void);
 static Statement *build_insert_string(void);
 static Statement *build_update_string(void);
 static Statement * build_select_string(bool key);
-static int generate_primary_key_list(drizzle_con_st *con, OptionString *engine_stmt);
-static int create_schema(drizzle_con_st *con, const char *db, Statement *stmt,
-                         OptionString *engine_stmt, Stats *sptr);
-static int run_scheduler(Stats *sptr, Statement **stmts, uint32_t concur,
-                         uint64_t limit);
+static int generate_primary_key_list(drizzle_con_st &con, OptionString *engine_stmt);
+static void create_schema(drizzle_con_st &con, const char *db, Statement *stmt, OptionString *engine_stmt, Stats *sptr);
+static void run_scheduler(Stats *sptr, Statement **stmts, uint32_t concur, uint64_t limit);
 void statement_cleanup(Statement *stmt);
 void option_cleanup(OptionString *stmt);
-void concurrency_loop(drizzle_con_st *con, uint32_t current, OptionString *eptr);
-static int run_statements(drizzle_con_st *con, Statement *stmt);
-void slap_connect(drizzle_con_st *con, bool connect_to_schema);
-void slap_close(drizzle_con_st *con);
-static int run_query(drizzle_con_st *con, drizzle_result_st *result, const char *query, int len);
-void standard_deviation (Conclusions *con, Stats *sptr);
+void concurrency_loop(drizzle_con_st &con, uint32_t current, OptionString *eptr);
+static void run_statements(drizzle_con_st &con, Statement *stmt);
+void slap_connect(drizzle_con_st &con, bool connect_to_schema);
+void slap_close(drizzle_con_st &con);
+static int run_query(drizzle_con_st &con, drizzle_result_st *result, const char *query, int len);
+void standard_deviation(Conclusions &con, Stats *sptr);
 
 static const char ALPHANUMERICS[]=
 "0123456789ABCDEFGHIJKLMNOPQRSTWXYZabcdefghijklmnopqrstuvwxyz";
@@ -271,20 +269,15 @@
 {
   uint64_t counter= 0, queries;
   uint64_t detach_counter;
-  unsigned int commit_counter;
+  uint32_t commit_counter;
   drizzle_con_st con;
   drizzle_result_st result;
   drizzle_row_t row;
   Statement *ptr;
 
-  sleeper_mutex.lock();
-  while (master_wakeup)
-  {
-    sleep_threshhold.wait(sleeper_mutex);
-  }
-  sleeper_mutex.unlock();
+  master_wakeup.wait();
 
-  slap_connect(&con, true);
+  slap_connect(con, true);
 
   if (verbose >= 3)
     printf("connected!\n");
@@ -292,17 +285,17 @@
 
   commit_counter= 0;
   if (commit_rate)
-    run_query(&con, NULL, "SET AUTOCOMMIT=0", strlen("SET AUTOCOMMIT=0"));
+    run_query(con, NULL, "SET AUTOCOMMIT=0", strlen("SET AUTOCOMMIT=0"));
 
 limit_not_met:
   for (ptr= ctx->getStmt(), detach_counter= 0;
        ptr && ptr->getLength();
        ptr= ptr->getNext(), detach_counter++)
   {
-    if (!opt_only_print && detach_rate && !(detach_counter % detach_rate))
+    if (not opt_only_print && detach_rate && !(detach_counter % detach_rate))
     {
-      slap_close(&con);
-      slap_connect(&con, true);
+      slap_close(con);
+      slap_connect(con, true);
     }
 
     /*
@@ -312,7 +305,7 @@
         (ptr->getType() == SELECT_TYPE_REQUIRES_PREFIX))
     {
       int length;
-      unsigned int key_val;
+      uint32_t key_val;
       char buffer[HUGE_STRING_LENGTH];
 
       /*
@@ -325,7 +318,7 @@
       assert(primary_keys.size());
       if (primary_keys.size())
       {
-        key_val= (unsigned int)(random() % primary_keys.size());
+        key_val= (uint32_t)(random() % primary_keys.size());
         const char *key;
         key= primary_keys[key_val].c_str();
 
@@ -334,25 +327,25 @@
         length= snprintf(buffer, HUGE_STRING_LENGTH, "%.*s '%s'",
                          (int)ptr->getLength(), ptr->getString(), key);
 
-        if (run_query(&con, &result, buffer, length))
+        if (run_query(con, &result, buffer, length))
         {
           fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
                   internal::my_progname, (uint32_t)length, buffer, drizzle_con_error(&con));
-          exit(1);
+          abort();
         }
       }
     }
     else
     {
-      if (run_query(&con, &result, ptr->getString(), ptr->getLength()))
+      if (run_query(con, &result, ptr->getString(), ptr->getLength()))
       {
         fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
                 internal::my_progname, (uint32_t)ptr->getLength(), ptr->getString(), drizzle_con_error(&con));
-        exit(1);
+        abort();
       }
     }
 
-    if (!opt_only_print)
+    if (not opt_only_print)
     {
       while ((row = drizzle_row_next(&result)))
         counter++;
@@ -363,7 +356,7 @@
     if (commit_rate && (++commit_counter == commit_rate))
     {
       commit_counter= 0;
-      run_query(&con, NULL, "COMMIT", strlen("COMMIT"));
+      run_query(con, NULL, "COMMIT", strlen("COMMIT"));
     }
 
     /* If the timer is set, and the alarm is not active then end */
@@ -384,9 +377,9 @@
 
 end:
   if (commit_rate)
-    run_query(&con, NULL, "COMMIT", strlen("COMMIT"));
+    run_query(con, NULL, "COMMIT", strlen("COMMIT"));
 
-  slap_close(&con);
+  slap_close(con);
 
   {
     boost::mutex::scoped_lock scopedLock(counter_mutex);
@@ -571,7 +564,7 @@
     po::notify(vm);
 
     if (process_options())
-      exit(1);
+      abort();
 
     if ( vm.count("help") || vm.count("info"))
     {
@@ -584,7 +577,7 @@
            "license\n");
       puts("Run a query multiple times against the server\n");
       cout << long_options << endl;
-      exit(0);
+      abort();
     }   
 
     if (vm.count("protocol"))
@@ -599,7 +592,7 @@
       else
       {
         cout << _("Error: Unknown protocol") << " '" << opt_protocol << "'" << endl;
-        exit(-1);
+        abort();
       }
     }
     if (vm.count("port")) 
@@ -609,7 +602,7 @@
       if ((temp_drizzle_port == 0) || (temp_drizzle_port > 65535))
       {
         fprintf(stderr, _("Value supplied for port is not valid.\n"));
-        exit(1);
+        abort();
       }
       else
       {
@@ -619,7 +612,7 @@
 
   if ( vm.count("password") )
   {
-    if (!opt_password.empty())
+    if (not opt_password.empty())
       opt_password.erase();
     if (password == PASSWORD_SENTINEL)
     {
@@ -642,21 +635,21 @@
     {
       printf("%s  Ver %s Distrib %s, for %s-%s (%s)\n",internal::my_progname, SLAP_VERSION,
           drizzle_version(),HOST_VENDOR,HOST_OS,HOST_CPU);
-      exit(0);
+      abort();
     }
 
     /* Seed the random number generator if we will be using it. */
     if (auto_generate_sql)
     {
       if (opt_set_random_seed == 0)
-        opt_set_random_seed= (unsigned int)time(NULL);
+        opt_set_random_seed= (uint32_t)time(NULL);
       srandom(opt_set_random_seed);
     }
 
     /* globals? Yes, so we only have to run strlen once */
     delimiter_length= delimiter.length();
 
-    slap_connect(&con, false);
+    slap_connect(con, false);
 
     /* Main iterations loop */
 burnin:
@@ -672,29 +665,29 @@
       if (concurrency.size())
       {
         for (current= &concurrency[0]; current && *current; current++)
-          concurrency_loop(&con, *current, eptr);
+          concurrency_loop(con, *current, eptr);
       }
       else
       {
         uint32_t infinite= 1;
         do {
-          concurrency_loop(&con, infinite, eptr);
+          concurrency_loop(con, infinite, eptr);
         }
         while (infinite++);
       }
 
-      if (!opt_preserve)
-        drop_schema(&con, create_schema_string.c_str());
+      if (not opt_preserve)
+        drop_schema(con, create_schema_string.c_str());
 
     } while (eptr ? (eptr= eptr->getNext()) : 0);
 
     if (opt_burnin)
       goto burnin;
 
-    slap_close(&con);
+    slap_close(con);
 
     /* now free all the strings we created */
-    if (!opt_password.empty())
+    if (not opt_password.empty())
       opt_password.erase();
 
     concurrency.clear();
@@ -726,7 +719,7 @@
   return 0;
 }
 
-void concurrency_loop(drizzle_con_st *con, uint32_t current, OptionString *eptr)
+void concurrency_loop(drizzle_con_st &con, uint32_t current, OptionString *eptr)
 {
   Stats *head_sptr;
   Stats *sptr;
@@ -737,7 +730,7 @@
   if (head_sptr == NULL)
   {
     fprintf(stderr,"Error allocating memory in concurrency_loop\n");
-    exit(1);
+    abort();
   }
 
   if (auto_actual_queries)
@@ -774,7 +767,7 @@
     if (commit_rate)
       run_query(con, NULL, "SET AUTOCOMMIT=0", strlen("SET AUTOCOMMIT=0"));
 
-    if (!pre_system.empty())
+    if (not pre_system.empty())
     {
       int ret= system(pre_system.c_str());
       assert(ret != -1);
@@ -793,7 +786,7 @@
     if (post_statements)
       run_statements(con, post_statements);
 
-    if (!post_system.empty())
+    if (not post_system.empty())
     {
       int ret=  system(post_system.c_str());
       assert(ret !=-1);
@@ -809,17 +802,16 @@
 
   generate_stats(&conclusion, eptr, head_sptr);
 
-  if (!opt_silent)
-    print_conclusions(&conclusion);
-  if (!opt_csv_str.empty())
-    print_conclusions_csv(&conclusion);
+  if (not opt_silent)
+    print_conclusions(conclusion);
+  if (not opt_csv_str.empty())
+    print_conclusions_csv(conclusion);
 
   delete [] head_sptr;
 }
 
 
-uint
-get_random_string(char *buf, size_t size)
+uint32_t get_random_string(char *buf, size_t size)
 {
   char *buf_ptr= buf;
 
@@ -839,7 +831,7 @@
 build_table_string(void)
 {
   char       buf[HUGE_STRING_LENGTH];
-  unsigned int        col_count;
+  uint32_t        col_count;
   Statement *ptr;
   string table_string;
 
@@ -865,9 +857,7 @@
 
   if (auto_generate_sql_secondary_indexes)
   {
-    unsigned int count;
-
-    for (count= 0; count < auto_generate_sql_secondary_indexes; count++)
+    for (uint32_t count= 0; count < auto_generate_sql_secondary_indexes; count++)
     {
       if (count) /* Except for the first pass we add a comma */
         table_string.append(",");
@@ -876,7 +866,7 @@
           > HUGE_STRING_LENGTH)
       {
         fprintf(stderr, "Memory Allocation error in create table\n");
-        exit(1);
+        abort();
       }
       table_string.append(buf);
     }
@@ -894,7 +884,7 @@
                      col_count, col_count) > HUGE_STRING_LENGTH)
         {
           fprintf(stderr, "Memory Allocation error in create table\n");
-          exit(1);
+          abort();
         }
       }
       else
@@ -903,7 +893,7 @@
             > HUGE_STRING_LENGTH)
         {
           fprintf(stderr, "Memory Allocation error in create table\n");
-          exit(1);
+          abort();
         }
       }
       table_string.append(buf);
@@ -922,7 +912,7 @@
                      col_count, col_count) > HUGE_STRING_LENGTH)
         {
           fprintf(stderr, "Memory Allocation error in creating table\n");
-          exit(1);
+          abort();
         }
       }
       else
@@ -931,7 +921,7 @@
                      col_count) > HUGE_STRING_LENGTH)
         {
           fprintf(stderr, "Memory Allocation error in creating table\n");
-          exit(1);
+          abort();
         }
       }
       table_string.append(buf);
@@ -947,7 +937,7 @@
                    col_count) > HUGE_STRING_LENGTH)
       {
         fprintf(stderr, "Memory Allocation error in creating table\n");
-        exit(1);
+        abort();
       }
       table_string.append(buf);
 
@@ -961,7 +951,7 @@
   if (ptr->getString()==NULL)
   {
     fprintf(stderr, "Memory Allocation error in creating table\n");
-    exit(1);
+    abort();
   }
   ptr->setType(CREATE_TABLE_TYPE);
   strcpy(ptr->getString(), table_string.c_str());
@@ -978,7 +968,7 @@
 build_update_string(void)
 {
   char       buf[HUGE_STRING_LENGTH];
-  unsigned int        col_count;
+  uint32_t        col_count;
   Statement *ptr;
   string update_string;
 
@@ -993,7 +983,7 @@
                    random()) > HUGE_STRING_LENGTH)
       {
         fprintf(stderr, "Memory Allocation error in creating update\n");
-        exit(1);
+        abort();
       }
       update_string.append(buf);
 
@@ -1012,7 +1002,7 @@
           > HUGE_STRING_LENGTH)
       {
         fprintf(stderr, "Memory Allocation error in creating update\n");
-        exit(1);
+        abort();
       }
       update_string.append(buf);
 
@@ -1030,7 +1020,7 @@
   if (ptr->getString() == NULL)
   {
     fprintf(stderr, "Memory Allocation error in creating update\n");
-    exit(1);
+    abort();
   }
   if (auto_generate_sql_autoincrement || auto_generate_sql_guid_primary)
     ptr->setType(UPDATE_TYPE_REQUIRES_PREFIX);
@@ -1051,7 +1041,7 @@
 build_insert_string(void)
 {
   char       buf[HUGE_STRING_LENGTH];
-  unsigned int        col_count;
+  uint32_t        col_count;
   Statement *ptr;
   string insert_string;
 
@@ -1077,7 +1067,7 @@
 
   if (auto_generate_sql_secondary_indexes)
   {
-    unsigned int count;
+    uint32_t count;
 
     for (count= 0; count < auto_generate_sql_secondary_indexes; count++)
     {
@@ -1097,7 +1087,7 @@
       if (snprintf(buf, HUGE_STRING_LENGTH, "%ld", random()) > HUGE_STRING_LENGTH)
       {
         fprintf(stderr, "Memory Allocation error in creating insert\n");
-        exit(1);
+        abort();
       }
       insert_string.append(buf);
 
@@ -1125,9 +1115,9 @@
 
     for (col_count= 1; col_count <= num_blob_cols; col_count++)
     {
-      unsigned int buf_len;
-      unsigned int size;
-      unsigned int difference= num_blob_cols_size - num_blob_cols_size_min;
+      uint32_t buf_len;
+      uint32_t size;
+      uint32_t difference= num_blob_cols_size - num_blob_cols_size_min;
 
       size= difference ? (num_blob_cols_size_min + (random() % difference)) :
         num_blob_cols_size;
@@ -1150,7 +1140,7 @@
   if (ptr->getString()==NULL)
   {
     fprintf(stderr, "Memory Allocation error in creating select\n");
-    exit(1);
+    abort();
   }
   ptr->setType(INSERT_TYPE);
   strcpy(ptr->getString(), insert_string.c_str());
@@ -1168,14 +1158,14 @@
 build_select_string(bool key)
 {
   char       buf[HUGE_STRING_LENGTH];
-  unsigned int        col_count;
+  uint32_t        col_count;
   Statement *ptr;
   string query_string;
 
   query_string.reserve(HUGE_STRING_LENGTH);
 
   query_string.append("SELECT ", 7);
-  if (!auto_generate_selected_columns_opt.empty())
+  if (not auto_generate_selected_columns_opt.empty())
   {
     query_string.append(auto_generate_selected_columns_opt.c_str());
   }
@@ -1187,7 +1177,7 @@
           > HUGE_STRING_LENGTH)
       {
         fprintf(stderr, "Memory Allocation error in creating select\n");
-        exit(1);
+        abort();
       }
       query_string.append(buf);
 
@@ -1201,7 +1191,7 @@
           > HUGE_STRING_LENGTH)
       {
         fprintf(stderr, "Memory Allocation error in creating select\n");
-        exit(1);
+        abort();
       }
       query_string.append(buf);
 
@@ -1215,7 +1205,7 @@
           > HUGE_STRING_LENGTH)
       {
         fprintf(stderr, "Memory Allocation error in creating select\n");
-        exit(1);
+        abort();
       }
       query_string.append(buf);
 
@@ -1234,7 +1224,7 @@
   if (ptr->getString() == NULL)
   {
     fprintf(stderr, "Memory Allocation error in creating select\n");
-    exit(1);
+    abort();
   }
   if ((key) &&
       (auto_generate_sql_autoincrement || auto_generate_sql_guid_primary))
@@ -1250,7 +1240,7 @@
 {
   struct stat sbuf;
   OptionString *sql_type;
-  unsigned int sql_type_count= 0;
+  uint32_t sql_type_count= 0;
   ssize_t bytes_read= 0;
   
   if (user.empty())
@@ -1259,15 +1249,15 @@
   verbose= opt_verbose.length();
 
   /* If something is created we clean it up, otherwise we leave schemas alone */
-  if ( (!create_string.empty()) || auto_generate_sql)
+  if ( (not create_string.empty()) || auto_generate_sql)
     opt_preserve= false;
 
-  if (auto_generate_sql && (!create_string.empty() || !user_supplied_query.empty()))
+  if (auto_generate_sql && (not create_string.empty() || !user_supplied_query.empty()))
   {
     fprintf(stderr,
             "%s: Can't use --auto-generate-sql when create and query strings are specified!\n",
             internal::my_progname);
-    exit(1);
+    abort();
   }
 
   if (auto_generate_sql && auto_generate_sql_guid_primary &&
@@ -1276,7 +1266,7 @@
     fprintf(stderr,
             "%s: Either auto-generate-sql-guid-primary or auto-generate-sql-add-autoincrement can be used!\n",
             internal::my_progname);
-    exit(1);
+    abort();
   }
 
   if (auto_generate_sql && num_of_query && auto_actual_queries)
@@ -1284,12 +1274,12 @@
     fprintf(stderr,
             "%s: Either auto-generate-sql-execute-number or number-of-queries can be used!\n",
             internal::my_progname);
-    exit(1);
+    abort();
   }
 
-  parse_comma(!concurrency_str.empty() ? concurrency_str.c_str() : "1", concurrency);
+  parse_comma(not concurrency_str.empty() ? concurrency_str.c_str() : "1", concurrency);
 
-  if (!opt_csv_str.empty())
+  if (not opt_csv_str.empty())
   {
     opt_silent= true;
 
@@ -1304,7 +1294,7 @@
       {
         fprintf(stderr,"%s: Could not open csv file: %sn\n",
                 internal::my_progname, opt_csv_str.c_str());
-        exit(1);
+        abort();
       }
     }
   }
@@ -1312,7 +1302,7 @@
   if (opt_only_print)
     opt_silent= true;
 
-  if (!num_int_cols_opt.empty())
+  if (not num_int_cols_opt.empty())
   {
     OptionString *str;
     parse_option(num_int_cols_opt.c_str(), &str, ',');
@@ -1322,7 +1312,7 @@
     option_cleanup(str);
   }
 
-  if (!num_char_cols_opt.empty())
+  if (not num_char_cols_opt.empty())
   {
     OptionString *str;
     parse_option(num_char_cols_opt.c_str(), &str, ',');
@@ -1334,7 +1324,7 @@
     option_cleanup(str);
   }
 
-  if (!num_blob_cols_opt.empty())
+  if (not num_blob_cols_opt.empty())
   {
     OptionString *str;
     parse_option(num_blob_cols_opt.c_str(), &str, ',');
@@ -1419,7 +1409,7 @@
           fprintf(stderr,
                   "%s: Can't perform key test without a primary key!\n",
                   internal::my_progname);
-          exit(1);
+          abort();
         }
 
         query_statements[sql_type_count]= build_select_string(true);
@@ -1455,7 +1445,7 @@
           fprintf(stderr,
                   "%s: Can't perform update test without a primary key!\n",
                   internal::my_progname);
-          exit(1);
+          abort();
         }
 
         query_statements[sql_type_count]= build_update_string();
@@ -1496,25 +1486,25 @@
   }
   else
   {
-    if (!create_string.empty() && !stat(create_string.c_str(), &sbuf))
+    if (not create_string.empty() && !stat(create_string.c_str(), &sbuf))
     {
       int data_file;
       std::vector<char> tmp_string;
-      if (!S_ISREG(sbuf.st_mode))
+      if (not S_ISREG(sbuf.st_mode))
       {
         fprintf(stderr,"%s: Create file was not a regular file\n",
                 internal::my_progname);
-        exit(1);
+        abort();
       }
       if ((data_file= open(create_string.c_str(), O_RDWR)) == -1)
       {
         fprintf(stderr,"%s: Could not open create file\n", internal::my_progname);
-        exit(1);
+        abort();
       }
       if ((uint64_t)(sbuf.st_size + 1) > SIZE_MAX)
       {
         fprintf(stderr, "Request for more memory than architecture supports\n");
-        exit(1);
+        abort();
       }
       tmp_string.resize(sbuf.st_size + 1);
       bytes_read= read(data_file, (unsigned char*) &tmp_string[0],
@@ -1526,13 +1516,13 @@
       }
       parse_delimiter(&tmp_string[0], &create_statements, delimiter[0]);
     }
-    else if (!create_string.empty())
+    else if (not create_string.empty())
     {
       parse_delimiter(create_string.c_str(), &create_statements, delimiter[0]);
     }
 
     /* Set this up till we fully support options on user generated queries */
-    if (!user_supplied_query.empty())
+    if (not user_supplied_query.empty())
     {
       query_statements_count=
         parse_option("default", &query_options, ',');
@@ -1540,26 +1530,26 @@
       query_statements.resize(query_statements_count);
     }
 
-    if (!user_supplied_query.empty() && !stat(user_supplied_query.c_str(), &sbuf))
+    if (not user_supplied_query.empty() && !stat(user_supplied_query.c_str(), &sbuf))
     {
       int data_file;
       std::vector<char> tmp_string;
 
-      if (!S_ISREG(sbuf.st_mode))
+      if (not S_ISREG(sbuf.st_mode))
       {
         fprintf(stderr,"%s: User query supplied file was not a regular file\n",
                 internal::my_progname);
-        exit(1);
+        abort();
       }
       if ((data_file= open(user_supplied_query.c_str(), O_RDWR)) == -1)
       {
         fprintf(stderr,"%s: Could not open query supplied file\n", internal::my_progname);
-        exit(1);
+        abort();
       }
       if ((uint64_t)(sbuf.st_size + 1) > SIZE_MAX)
       {
         fprintf(stderr, "Request for more memory than architecture supports\n");
-        exit(1);
+        abort();
       }
       tmp_string.resize((size_t)(sbuf.st_size + 1));
       bytes_read= read(data_file, (unsigned char*) &tmp_string[0],
@@ -1569,38 +1559,38 @@
       {
         fprintf(stderr, "Problem reading file: read less bytes than requested\n");
       }
-      if (!user_supplied_query.empty())
+      if (not user_supplied_query.empty())
         actual_queries= parse_delimiter(&tmp_string[0], &query_statements[0],
                                         delimiter[0]);
     }
-    else if (!user_supplied_query.empty())
+    else if (not user_supplied_query.empty())
     {
       actual_queries= parse_delimiter(user_supplied_query.c_str(), &query_statements[0],
                                       delimiter[0]);
     }
   }
 
-  if (!user_supplied_pre_statements.empty()
+  if (not user_supplied_pre_statements.empty()
       && !stat(user_supplied_pre_statements.c_str(), &sbuf))
   {
     int data_file;
     std::vector<char> tmp_string;
 
-    if (!S_ISREG(sbuf.st_mode))
+    if (not S_ISREG(sbuf.st_mode))
     {
       fprintf(stderr,"%s: User query supplied file was not a regular file\n",
               internal::my_progname);
-      exit(1);
+      abort();
     }
     if ((data_file= open(user_supplied_pre_statements.c_str(), O_RDWR)) == -1)
     {
       fprintf(stderr,"%s: Could not open query supplied file\n", internal::my_progname);
-      exit(1);
+      abort();
     }
     if ((uint64_t)(sbuf.st_size + 1) > SIZE_MAX)
     {
       fprintf(stderr, "Request for more memory than architecture supports\n");
-      exit(1);
+      abort();
     }
     tmp_string.resize((size_t)(sbuf.st_size + 1));
     bytes_read= read(data_file, (unsigned char*) &tmp_string[0],
@@ -1610,39 +1600,39 @@
     {
       fprintf(stderr, "Problem reading file: read less bytes than requested\n");
     }
-    if (!user_supplied_pre_statements.empty())
+    if (not user_supplied_pre_statements.empty())
       (void)parse_delimiter(&tmp_string[0], &pre_statements,
                             delimiter[0]);
   }
-  else if (!user_supplied_pre_statements.empty())
+  else if (not user_supplied_pre_statements.empty())
   {
     (void)parse_delimiter(user_supplied_pre_statements.c_str(),
                           &pre_statements,
                           delimiter[0]);
   }
 
-  if (!user_supplied_post_statements.empty()
+  if (not user_supplied_post_statements.empty()
       && !stat(user_supplied_post_statements.c_str(), &sbuf))
   {
     int data_file;
     std::vector<char> tmp_string;
 
-    if (!S_ISREG(sbuf.st_mode))
+    if (not S_ISREG(sbuf.st_mode))
     {
       fprintf(stderr,"%s: User query supplied file was not a regular file\n",
               internal::my_progname);
-      exit(1);
+      abort();
     }
     if ((data_file= open(user_supplied_post_statements.c_str(), O_RDWR)) == -1)
     {
       fprintf(stderr,"%s: Could not open query supplied file\n", internal::my_progname);
-      exit(1);
+      abort();
     }
 
     if ((uint64_t)(sbuf.st_size + 1) > SIZE_MAX)
     {
       fprintf(stderr, "Request for more memory than architecture supports\n");
-      exit(1);
+      abort();
     }
     tmp_string.resize((size_t)(sbuf.st_size + 1));
 
@@ -1653,11 +1643,11 @@
     {
       fprintf(stderr, "Problem reading file: read less bytes than requested\n");
     }
-    if (!user_supplied_post_statements.empty())
+    if (not user_supplied_post_statements.empty())
       (void)parse_delimiter(&tmp_string[0], &post_statements,
                             delimiter[0]);
   }
-  else if (!user_supplied_post_statements.empty())
+  else if (not user_supplied_post_statements.empty())
   {
     (void)parse_delimiter(user_supplied_post_statements.c_str(), &post_statements,
                           delimiter[0]);
@@ -1666,7 +1656,7 @@
   if (verbose >= 2)
     printf("Parsing engines to use.\n");
 
-  if (!default_engine.empty())
+  if (not default_engine.empty())
     parse_option(default_engine.c_str(), &engine_options, ',');
 
   if (tty_password)
@@ -1675,7 +1665,7 @@
 }
 
 
-static int run_query(drizzle_con_st *con, drizzle_result_st *result,
+static int run_query(drizzle_con_st &con, drizzle_result_st *result,
                      const char *query, int len)
 {
   drizzle_return_t ret;
@@ -1693,7 +1683,7 @@
   if (result == NULL)
     result= &result_buffer;
 
-  result= drizzle_query(con, result, query, len, &ret);
+  result= drizzle_query(&con, result, query, len, &ret);
 
   if (ret == DRIZZLE_RETURN_OK)
     ret= drizzle_result_buffer(result);
@@ -1706,7 +1696,7 @@
 
 
 static int
-generate_primary_key_list(drizzle_con_st *con, OptionString *engine_stmt)
+generate_primary_key_list(drizzle_con_st &con, OptionString *engine_stmt)
 {
   drizzle_result_st result;
   drizzle_row_t row;
@@ -1728,15 +1718,15 @@
     if (run_query(con, &result, "SELECT id from t1", strlen("SELECT id from t1")))
     {
       fprintf(stderr,"%s: Cannot select GUID primary keys. (%s)\n", internal::my_progname,
-              drizzle_con_error(con));
-      exit(1);
+              drizzle_con_error(&con));
+      abort();
     }
 
     uint64_t num_rows_ret= drizzle_result_row_count(&result);
     if (num_rows_ret > SIZE_MAX)
     {
       fprintf(stderr, "More primary keys than than architecture supports\n");
-      exit(1);
+      abort();
     }
     size_t primary_keys_number_of;
     primary_keys_number_of= (size_t)num_rows_ret;
@@ -1761,15 +1751,12 @@
   return(0);
 }
 
-static int
-create_schema(drizzle_con_st *con, const char *db, Statement *stmt,
-              OptionString *engine_stmt, Stats *sptr)
+static void create_schema(drizzle_con_st &con, const char *db, Statement *stmt, OptionString *engine_stmt, Stats *sptr)
 {
   char query[HUGE_STRING_LENGTH];
   Statement *ptr;
   Statement *after_create;
   int len;
-  uint64_t count;
   struct timeval start_time, end_time;
 
 
@@ -1783,8 +1770,8 @@
   if (run_query(con, NULL, query, len))
   {
     fprintf(stderr,"%s: Cannot create schema %s : %s\n", internal::my_progname, db,
-            drizzle_con_error(con));
-    exit(1);
+            drizzle_con_error(&con));
+    abort();
   }
   else
   {
@@ -1803,13 +1790,13 @@
     if (verbose >= 3)
       printf("%s;\n", query);
 
-    if (drizzle_select_db(con,  &result, db, &ret) == NULL ||
+    if (drizzle_select_db(&con,  &result, db, &ret) == NULL ||
         ret != DRIZZLE_RETURN_OK)
     {
       fprintf(stderr,"%s: Cannot select schema '%s': %s\n",internal::my_progname, db,
               ret == DRIZZLE_RETURN_ERROR_CODE ?
-              drizzle_result_error(&result) : drizzle_con_error(con));
-      exit(1);
+              drizzle_result_error(&result) : drizzle_con_error(&con));
+      abort();
     }
     drizzle_result_free(&result);
     sptr->setCreateCount(sptr->getCreateCount()+1);
@@ -1822,13 +1809,13 @@
     if (run_query(con, NULL, query, len))
     {
       fprintf(stderr,"%s: Cannot set default engine: %s\n", internal::my_progname,
-              drizzle_con_error(con));
-      exit(1);
+              drizzle_con_error(&con));
+      abort();
     }
     sptr->setCreateCount(sptr->getCreateCount()+1);
   }
 
-  count= 0;
+  uint64_t count= 0;
   after_create= stmt;
 
 limit_not_met:
@@ -1846,9 +1833,9 @@
       if (run_query(con, NULL, buffer, strlen(buffer)))
       {
         fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
-                internal::my_progname, (uint32_t)ptr->getLength(), ptr->getString(), drizzle_con_error(con));
-        if (!opt_ignore_sql_errors)
-          exit(1);
+                internal::my_progname, (uint32_t)ptr->getLength(), ptr->getString(), drizzle_con_error(&con));
+        if (not opt_ignore_sql_errors)
+          abort();
       }
       sptr->setCreateCount(sptr->getCreateCount()+1);
     }
@@ -1857,9 +1844,9 @@
       if (run_query(con, NULL, ptr->getString(), ptr->getLength()))
       {
         fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
-                internal::my_progname, (uint32_t)ptr->getLength(), ptr->getString(), drizzle_con_error(con));
-        if (!opt_ignore_sql_errors)
-          exit(1);
+                internal::my_progname, (uint32_t)ptr->getLength(), ptr->getString(), drizzle_con_error(&con));
+        if (not opt_ignore_sql_errors)
+          abort();
       }
       sptr->setCreateCount(sptr->getCreateCount()+1);
     }
@@ -1875,12 +1862,9 @@
   gettimeofday(&end_time, NULL);
 
   sptr->setCreateTiming(timedif(end_time, start_time));
-
-  return(0);
 }
 
-static int
-drop_schema(drizzle_con_st *con, const char *db)
+static void drop_schema(drizzle_con_st &con, const char *db)
 {
   char query[HUGE_STRING_LENGTH];
   int len;
@@ -1890,31 +1874,22 @@
   if (run_query(con, NULL, query, len))
   {
     fprintf(stderr,"%s: Cannot drop database '%s' ERROR : %s\n",
-            internal::my_progname, db, drizzle_con_error(con));
-    exit(1);
+            internal::my_progname, db, drizzle_con_error(&con));
+    abort();
   }
-
-
-
-  return(0);
 }
 
-static int
-run_statements(drizzle_con_st *con, Statement *stmt)
+static void run_statements(drizzle_con_st &con, Statement *stmt)
 {
-  Statement *ptr;
-
-  for (ptr= stmt; ptr && ptr->getLength(); ptr= ptr->getNext())
+  for (Statement *ptr= stmt; ptr && ptr->getLength(); ptr= ptr->getNext())
   {
     if (run_query(con, NULL, ptr->getString(), ptr->getLength()))
     {
       fprintf(stderr,"%s: Cannot run query %.*s ERROR : %s\n",
-              internal::my_progname, (uint32_t)ptr->getLength(), ptr->getString(), drizzle_con_error(con));
-      exit(1);
+              internal::my_progname, (uint32_t)ptr->getLength(), ptr->getString(), drizzle_con_error(&con));
+      abort();
     }
   }
-
-  return(0);
 }
 
 
@@ -1924,12 +1899,7 @@
     We lock around the initial call in case were we in a loop. This
     also keeps the value properly syncronized across call threads.
   */
-  sleeper_mutex.lock();
-  while (master_wakeup)
-  {
-    sleep_threshhold.wait(sleeper_mutex);
-  }
-  sleeper_mutex.unlock();
+  master_wakeup.wait();
 
   {
     boost::mutex::scoped_lock scopedLock(timer_alarm_mutex);
@@ -1947,10 +1917,9 @@
   }
 }
 
-static int
-run_scheduler(Stats *sptr, Statement **stmts, uint32_t concur, uint64_t limit)
+static void run_scheduler(Stats *sptr, Statement **stmts, uint32_t concur, uint64_t limit)
 {
-  unsigned int real_concurrency;
+  uint32_t real_concurrency;
   struct timeval start_time, end_time;
 
   {
@@ -1959,10 +1928,7 @@
     OptionString *sql_type;
     thread_counter= 0;
 
-    {
-      boost::mutex::scoped_lock scopedWakeup(sleeper_mutex);
-      master_wakeup= true;
-    }
+    master_wakeup.reset();
 
     real_concurrency= 0;
 
@@ -1971,7 +1937,7 @@
          y < query_statements_count;
          y++, sql_type= sql_type->getNext())
     {
-      unsigned int options_loop= 1;
+      uint32_t options_loop= 1;
 
       if (sql_type->getOption())
       {
@@ -1989,7 +1955,7 @@
           if (con == NULL)
           {
             fprintf(stderr, "Memory Allocation error in scheduler\n");
-            exit(1);
+            abort();
           }
           con->setStmt(stmts[y]);
           con->setLimit(limit);
@@ -2018,11 +1984,7 @@
     }
   }
 
-  {
-    boost::mutex::scoped_lock scopedSleeper(sleeper_mutex);
-    master_wakeup= false;
-  }
-  sleep_threshhold.notify_all();
+  master_wakeup.start();
 
   gettimeofday(&start_time, NULL);
 
@@ -2047,16 +2009,13 @@
   sptr->setUsers(concur);
   sptr->setRealUsers(real_concurrency);
   sptr->setRows(limit);
-
-  return(0);
 }
 
 /*
   Parse records from comma seperated string. : is a reserved character and is used for options
   on variables.
 */
-uint
-parse_option(const char *origin, OptionString **stmt, char delm)
+uint32_t parse_option(const char *origin, OptionString **stmt, char delm)
 {
   char *string;
   char *begin_ptr;
@@ -2106,7 +2065,7 @@
     if (tmp->getString() == NULL)
     {
       fprintf(stderr,"Error allocating memory while parsing options\n");
-      exit(1);
+      abort();
     }
 
     if (isspace(*begin_ptr))
@@ -2129,8 +2088,7 @@
   Raw parsing interface. If you want the slap specific parser look at
   parse_option.
 */
-uint
-parse_delimiter(const char *script, Statement **stmt, char delm)
+uint32_t parse_delimiter(const char *script, Statement **stmt, char delm)
 {
   char *retstr;
   char *ptr= (char *)script;
@@ -2147,7 +2105,7 @@
     if (tmp == NULL)
     {
       fprintf(stderr,"Error allocating memory while parsing delimiter\n");
-      exit(1);
+      abort();
     }
 
     count++;
@@ -2156,7 +2114,7 @@
     if (tmp->getString() == NULL)
     {
       fprintf(stderr,"Error allocating memory while parsing delimiter\n");
-      exit(1);
+      abort();
     }
 
     memcpy(tmp->getString(), ptr, tmp->getLength());
@@ -2171,7 +2129,7 @@
     if (tmp->getString() == NULL)
     {
       fprintf(stderr,"Error allocating memory while parsing delimiter\n");
-      exit(1);
+      abort();
     }
     memcpy(tmp->getString(), ptr, tmp->getLength());
     count++;
@@ -2186,13 +2144,12 @@
   number ranges from a comma seperated string.
   In restrospect, this is a lousy name from this function.
 */
-uint
-parse_comma(const char *string, std::vector <uint32_t> &range)
+uint32_t parse_comma(const char *string, std::vector <uint32_t> &range)
 {
-  unsigned int count= 1,x; /* We know that there is always one */
+  uint32_t count= 1; /* We know that there is always one */
   char *retstr;
   char *ptr= (char *)string;
-  unsigned int *nptr;
+  uint32_t *nptr;
 
   for (;*ptr; ptr++)
     if (*ptr == ',') count++;
@@ -2202,7 +2159,7 @@
   nptr= &range[0];
 
   ptr= (char *)string;
-  x= 0;
+  uint32_t x= 0;
   while ((retstr= strchr(ptr,',')))
   {
     nptr[x++]= atoi(ptr);
@@ -2213,40 +2170,38 @@
   return count;
 }
 
-void
-print_conclusions(Conclusions *con)
+void print_conclusions(Conclusions &con)
 {
   printf("Benchmark\n");
-  if (con->getEngine())
-    printf("\tRunning for engine %s\n", con->getEngine());
-  if (!opt_label.empty() || !opt_auto_generate_sql_type.empty())
+  if (con.getEngine())
+    printf("\tRunning for engine %s\n", con.getEngine());
+
+  if (not opt_label.empty() || !opt_auto_generate_sql_type.empty())
   {
     const char *ptr= opt_auto_generate_sql_type.c_str() ? opt_auto_generate_sql_type.c_str() : "query";
     printf("\tLoad: %s\n", !opt_label.empty() ? opt_label.c_str() : ptr);
   }
   printf("\tAverage Time took to generate schema and initial data: %ld.%03ld seconds\n",
-         con->getCreateAvgTiming() / 1000, con->getCreateAvgTiming() % 1000);
+         con.getCreateAvgTiming() / 1000, con.getCreateAvgTiming() % 1000);
   printf("\tAverage number of seconds to run all queries: %ld.%03ld seconds\n",
-         con->getAvgTiming() / 1000, con->getAvgTiming() % 1000);
+         con.getAvgTiming() / 1000, con.getAvgTiming() % 1000);
   printf("\tMinimum number of seconds to run all queries: %ld.%03ld seconds\n",
-         con->getMinTiming() / 1000, con->getMinTiming() % 1000);
+         con.getMinTiming() / 1000, con.getMinTiming() % 1000);
   printf("\tMaximum number of seconds to run all queries: %ld.%03ld seconds\n",
-         con->getMaxTiming() / 1000, con->getMaxTiming() % 1000);
+         con.getMaxTiming() / 1000, con.getMaxTiming() % 1000);
   printf("\tTotal time for tests: %ld.%03ld seconds\n",
-         con->getSumOfTime() / 1000, con->getSumOfTime() % 1000);
-  printf("\tStandard Deviation: %ld.%03ld\n", con->getStdDev() / 1000, con->getStdDev() % 1000);
-  printf("\tNumber of queries in create queries: %"PRIu64"\n", con->getCreateCount());
+         con.getSumOfTime() / 1000, con.getSumOfTime() % 1000);
+  printf("\tStandard Deviation: %ld.%03ld\n", con.getStdDev() / 1000, con.getStdDev() % 1000);
+  printf("\tNumber of queries in create queries: %"PRIu64"\n", con.getCreateCount());
   printf("\tNumber of clients running queries: %u/%u\n",
-         con->getUsers(), con->getRealUsers());
+         con.getUsers(), con.getRealUsers());
   printf("\tNumber of times test was run: %u\n", iterations);
-  printf("\tAverage number of queries per client: %"PRIu64"\n", con->getAvgRows());
+  printf("\tAverage number of queries per client: %"PRIu64"\n", con.getAvgRows());
   printf("\n");
 }
 
-void
-print_conclusions_csv(Conclusions *con)
+void print_conclusions_csv(Conclusions &con)
 {
-  unsigned int x;
   char buffer[HUGE_STRING_LENGTH];
   char label_buffer[HUGE_STRING_LENGTH];
   size_t string_len;
@@ -2254,11 +2209,11 @@
 
   memset(label_buffer, 0, sizeof(label_buffer));
 
-  if (!opt_label.empty())
+  if (not opt_label.empty())
   {
     string_len= opt_label.length();
 
-    for (x= 0; x < string_len; x++)
+    for (uint32_t x= 0; x < string_len; x++)
     {
       if (temp_label[x] == ',')
         label_buffer[x]= '-';
@@ -2266,11 +2221,11 @@
         label_buffer[x]= temp_label[x] ;
     }
   }
-  else if (!opt_auto_generate_sql_type.empty())
+  else if (not opt_auto_generate_sql_type.empty())
   {
     string_len= opt_auto_generate_sql_type.length();
 
-    for (x= 0; x < string_len; x++)
+    for (uint32_t x= 0; x < string_len; x++)
     {
       if (opt_auto_generate_sql_type[x] == ',')
         label_buffer[x]= '-';
@@ -2286,17 +2241,17 @@
   snprintf(buffer, HUGE_STRING_LENGTH,
            "%s,%s,%ld.%03ld,%ld.%03ld,%ld.%03ld,%ld.%03ld,%ld.%03ld,"
            "%u,%u,%u,%"PRIu64"\n",
-           con->getEngine() ? con->getEngine() : "", /* Storage engine we ran against */
+           con.getEngine() ? con.getEngine() : "", /* Storage engine we ran against */
            label_buffer, /* Load type */
-           con->getAvgTiming() / 1000, con->getAvgTiming() % 1000, /* Time to load */
-           con->getMinTiming() / 1000, con->getMinTiming() % 1000, /* Min time */
-           con->getMaxTiming() / 1000, con->getMaxTiming() % 1000, /* Max time */
-           con->getSumOfTime() / 1000, con->getSumOfTime() % 1000, /* Total time */
-           con->getStdDev() / 1000, con->getStdDev() % 1000, /* Standard Deviation */
+           con.getAvgTiming() / 1000, con.getAvgTiming() % 1000, /* Time to load */
+           con.getMinTiming() / 1000, con.getMinTiming() % 1000, /* Min time */
+           con.getMaxTiming() / 1000, con.getMaxTiming() % 1000, /* Max time */
+           con.getSumOfTime() / 1000, con.getSumOfTime() % 1000, /* Total time */
+           con.getStdDev() / 1000, con.getStdDev() % 1000, /* Standard Deviation */
            iterations, /* Iterations */
-           con->getUsers(), /* Children used max_timing */
-           con->getRealUsers(), /* Children used max_timing */
-           con->getAvgRows()  /* Queries run */
+           con.getUsers(), /* Children used max_timing */
+           con.getRealUsers(), /* Children used max_timing */
+           con.getAvgRows()  /* Queries run */
            );
   size_t buff_len= strlen(buffer);
   ssize_t write_ret= write(csv_file, (unsigned char*) buffer, buff_len);
@@ -2309,11 +2264,10 @@
   }
 }
 
-void
-generate_stats(Conclusions *con, OptionString *eng, Stats *sptr)
+void generate_stats(Conclusions *con, OptionString *eng, Stats *sptr)
 {
   Stats *ptr;
-  unsigned int x;
+  uint32_t x;
 
   con->setMinTiming(sptr->getTiming());
   con->setMaxTiming(sptr->getTiming());
@@ -2343,7 +2297,7 @@
   else
     con->setEngine(NULL);
 
-  standard_deviation(con, sptr);
+  standard_deviation(*con, sptr);
 
   /* Now we do the create time operations */
   con->setCreateMinTiming(sptr->getCreateTiming());
@@ -2379,11 +2333,10 @@
   }
 }
 
-void
-statement_cleanup(Statement *stmt)
+void statement_cleanup(Statement *stmt)
 {
   Statement *ptr, *nptr;
-  if (!stmt)
+  if (not stmt)
     return;
 
   for (ptr= stmt; ptr; ptr= nptr)
@@ -2393,15 +2346,15 @@
   }
 }
 
-void slap_close(drizzle_con_st *con)
+void slap_close(drizzle_con_st &con)
 {
   if (opt_only_print)
     return;
 
-  drizzle_free(drizzle_con_drizzle(con));
+  drizzle_free(drizzle_con_drizzle(&con));
 }
 
-void slap_connect(drizzle_con_st *con, bool connect_to_schema)
+void slap_connect(drizzle_con_st &con, bool connect_to_schema)
 {
   /* Connect to server */
   static uint32_t connection_retry_sleep= 100000; /* Microseconds */
@@ -2416,19 +2369,19 @@
     usleep(random()%opt_delayed_start);
 
   if ((drizzle= drizzle_create(NULL)) == NULL ||
-      drizzle_con_add_tcp(drizzle, con, host.c_str(), opt_drizzle_port,
+      drizzle_con_add_tcp(drizzle, &con, host.c_str(), opt_drizzle_port,
         user.c_str(),
         opt_password.c_str(),
         connect_to_schema ? create_schema_string.c_str() : NULL,
         use_drizzle_protocol ? DRIZZLE_CON_EXPERIMENTAL : DRIZZLE_CON_MYSQL) == NULL)
   {
     fprintf(stderr,"%s: Error creating drizzle object\n", internal::my_progname);
-    exit(1);
+    abort();
   }
 
   for (uint32_t x= 0; x < 10; x++)
   {
-    if ((ret= drizzle_con_connect(con)) == DRIZZLE_RETURN_OK)
+    if ((ret= drizzle_con_connect(&con)) == DRIZZLE_RETURN_OK)
     {
       /* Connect suceeded */
       connect_error= 0;
@@ -2439,33 +2392,32 @@
   if (connect_error)
   {
     fprintf(stderr,"%s: Error when connecting to server: %d %s\n", internal::my_progname,
-            ret, drizzle_con_error(con));
-    exit(1);
+            ret, drizzle_con_error(&con));
+    abort();
   }
 }
 
-void
-standard_deviation (Conclusions *con, Stats *sptr)
+void standard_deviation(Conclusions &con, Stats *sptr)
 {
-  unsigned int x;
   long int sum_of_squares;
   double the_catch;
   Stats *ptr;
 
   if (iterations == 1 || iterations == 0)
   {
-    con->setStdDev(0);
+    con.setStdDev(0);
     return;
   }
 
+  uint32_t x;
   for (ptr= sptr, x= 0, sum_of_squares= 0; x < iterations; ptr++, x++)
   {
     long int deviation;
 
-    deviation= ptr->getTiming() - con->getAvgTiming();
+    deviation= ptr->getTiming() - con.getAvgTiming();
     sum_of_squares+= deviation*deviation;
   }
 
   the_catch= sqrt((double)(sum_of_squares/(iterations -1)));
-  con->setStdDev((long int)the_catch);
+  con.setStdDev((long int)the_catch);
 }

=== modified file 'client/include.am'
--- client/include.am	2010-10-14 18:17:09 +0000
+++ client/include.am	2010-11-01 06:01:49 +0000
@@ -34,14 +34,15 @@
 		 client/errname.h \
 		 client/get_password.h \
 		 client/linebuffer.h \
+                 client/conclusions.h \
                  client/drizzledump_data.h \
+                 client/drizzledump_drizzle.h \
                  client/drizzledump_mysql.h \
-                 client/drizzledump_drizzle.h \
+                 client/option_string.h \
                  client/statement.h \
-                 client/option_string.h \
                  client/stats.h \
                  client/thread_context.h \
-                 client/conclusions.h
+                 client/wakeup.h
 
 client_drizzle_SOURCES=		client/drizzle.cc client/linebuffer.cc
 client_drizzle_LDADD=		${READLINE_LIBS} ${BOOST_LIBS} \
@@ -50,10 +51,12 @@
 				$(LIBZ) \
 				client/libgetpassword.la
 
-client_drizzledump_SOURCES=	client/drizzledump.cc \
-                                client/drizzledump_data.cc \
-                                client/drizzledump_mysql.cc \
-                                client/drizzledump_drizzle.cc
+client_drizzledump_SOURCES= \
+			    client/drizzledump.cc \
+			    client/drizzledump_data.cc \
+			    client/drizzledump_drizzle.cc \
+			    client/drizzledump_mysql.cc
+
 client_drizzledump_LDADD=	${CLIENT_LDADD} ${BOOST_LIBS}
 
 client_drizzleimport_SOURCES=	client/drizzleimport.cc

=== added file 'client/wakeup.h'
--- client/wakeup.h	1970-01-01 00:00:00 +0000
+++ client/wakeup.h	2010-11-01 06:01:49 +0000
@@ -0,0 +1,66 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include <boost/thread/mutex.hpp>
+#include <boost/thread/condition_variable.hpp>
+
+#ifndef CLIENT_WAKEUP_H
+#define CLIENT_WAKEUP_H
+
+namespace client {
+
+// Wakeup starts in a blocking posistion
+class Wakeup {
+  bool sleeping;
+  boost::mutex sleeper_mutex;
+  boost::condition_variable_any sleep_threshhold;
+
+public:
+  Wakeup() :
+    sleeping(true)
+  { }
+
+  void start()
+  {
+    boost::mutex::scoped_lock scopedWakeup(sleeper_mutex);
+    sleeping= false;
+    sleep_threshhold.notify_all();
+  }
+
+  void reset()
+  {
+    boost::mutex::scoped_lock scopedWakeup(sleeper_mutex);
+    sleeping= true;
+  }
+
+  void wait() 
+  {
+    sleeper_mutex.lock();
+    while (sleeping)
+    {
+      sleep_threshhold.wait(sleeper_mutex);
+    }
+    sleeper_mutex.unlock();
+  }
+};
+
+} // namespace client
+
+#endif /* CLIENT_WAKEUP_H */

=== modified file 'plugin/pbms/src/repository_ms.cc'
--- plugin/pbms/src/repository_ms.cc	2010-10-18 21:21:20 +0000
+++ plugin/pbms/src/repository_ms.cc	2010-11-02 15:38:34 +0000
@@ -742,7 +742,7 @@
 		alias_offset = 0;
 	}
 #else
-	uint32_t alias_hash = -1;
+	uint32_t alias_hash = ((uint32_t)-1);
 	if (alias || reset_alias) {
 		CSException::throwException(CS_CONTEXT, MS_ERR_NOT_IMPLEMENTED, "No BLOB alias support.");
 	}

